@@ -52,7 +52,7 @@ int main(int argc,char* argv[]){
     }
     else if(opt=='?'){
       fprintf(stderr,"option %c not recognized\n",optopt);
-      return(-1);
+      exit(-1);
     }
     else if(opt=='h'){
       /*print help*/
@@ -83,7 +83,7 @@ int main(int argc,char* argv[]){
       fprintf(stdout," gbacorr -t 0,2 'file(1)'    first three a.c. coeff. of the first data column\n");
       fprintf(stdout," gbacorr -p 0.05 'file(1:2)' x-corr of the first two columns together with\n");
       fprintf(stdout,"                             their 5%% confidence intervals\n");
-      return(0);
+      exit(0);
     }
     else if(opt=='t'){
       /*set the lead-lag range */
@@ -249,5 +249,5 @@ int main(int argc,char* argv[]){
     }
   }
 
-  return(0);
+  exit(0);
 }
