@@ -94,7 +94,7 @@ int main(int argc,char* argv[]){
     }
     else if(opt=='?'){
       fprintf(stderr,"option %c not recognized\n",optopt);
-      return(-1);
+      exit(-1);
     }
     else if(opt=='r'){
       /*reverse the order*/
