@@ -46,7 +46,7 @@ int main(int argc,char* argv[]){
     }
     else if(opt=='?'){
       fprintf(stderr,"option %c not recognized\n",optopt);
-      return(-1);
+      exit(-1);
     }
     else if(opt=='h'){
       /*print help*/
@@ -61,7 +61,7 @@ int main(int argc,char* argv[]){
       fprintf(stdout," -F  specify the input fields separators (default \" \\t\")\n");
       fprintf(stdout," -h  this help\n");
       fprintf(stdout," -v  verbose mode\n");
-      return(0);
+      exit(0);
     }
     else if(opt=='F'){
       /*set the fields separator string*/
