@@ -95,7 +95,7 @@ int main(int argc,char* argv[]){
     }
     else if(opt=='?'){
       fprintf(stderr,"option %c not recognized\n",optopt);
-      return(-1);
+      exit(-1);
     }
     else if(opt=='h'){
       /*print help*/
@@ -143,7 +143,7 @@ int main(int argc,char* argv[]){
       fprintf(stdout,"  gbhill pareto1 1 1 < file.dat  estimate the Pareto type 1 distribution, \n");
       fprintf(stdout,"                                 initial values are gamma=1 and b=1 \n");
       fprintf(stdout,"  gbhill -u .2 pareto1 1 1 < file.dat  the same using only top 20%% observations\n");
-      return(0);
+      exit(0);
     }
     else if(opt=='u'){
       /* set the fields separator string */
