@@ -46,7 +46,7 @@ int main(int argc,char* argv[]){
     }
     else if(opt=='?'){
 	    fprintf(stderr,"option %c not recognized\n",optopt);
-	    return(-1);
+	    exit(-1);
 	}
 	else if(opt=='F'){
 	  /*set the fields separator string*/
@@ -71,7 +71,7 @@ int main(int argc,char* argv[]){
 	  fprintf(stdout," -n  print a progressive tailing integer\n");
 	  fprintf(stdout," -F  specify the input fields separators (default \" \\t\")\n");
 	  fprintf(stdout," -h  this help\n");
-	  return(0);
+	  exit(0);
 	}
     }
     /* END OF COMMAND LINE PROCESSING */
