@@ -358,7 +358,7 @@ int main(int argc,char* argv[]){
     }
     else if(opt=='?'){
 	fprintf(stderr,"option %c not recognized\n",optopt);
-	return(-1);
+	exit(-1);
       }
       else if(opt=='n'){
 	/*the number of bins*/
@@ -377,7 +377,7 @@ int main(int argc,char* argv[]){
 	if(!strchr (optarg,',')){
 	fprintf(stderr,
 		"option -r requires comma separated couple of values\n");
-	return(-1);
+	exit(-1);
 	}
 	else{
 	  char *stmp1=strdup (optarg);
