@@ -55,7 +55,7 @@ int main(int argc,char* argv[]){
     }
     else if(opt=='?'){
       fprintf(stderr,"option %c not recognized\n",optopt);
-      return(-1);
+      exit(-1);
     }
     else if(opt=='F'){
       /*set the fields separator string*/
@@ -133,7 +133,7 @@ int main(int argc,char* argv[]){
       fprintf(stdout,"     option -D     \n");
       fprintf(stdout," -F  specify the input fields separators (default \" \\t\")\n");
       fprintf(stdout," -h  this help\n");
-      return(0);
+      exit(0);
     }
   }
   /* END OF COMMAND LINE PROCESSING */
