@@ -1554,7 +1554,7 @@ int main(int argc,char* argv[]){
     }
     else if(opt=='?'){
       fprintf(stderr,"option %c not recognized\n",optopt);
-      return(-1);
+      exit(-1);
     }
     else if(opt=='h'){
       /*print help*/
@@ -1610,7 +1610,7 @@ Options:\n\
 Examples:\n\
  gbnlpanel 'x1-a*x2-c,a=0,c=0' < data.dat  linear panel regression with one independent\n\
                                            variable\n");
-      return(0);
+      exit(0);
     }
     else if(opt=='A'){
    
