@@ -372,7 +372,7 @@ int main(int argc,char* argv[]){
     }
     else if(opt=='?'){
       fprintf(stderr,"option %c not recognized\n",optopt);
-      return(-1);
+      exit(-1);
     }
     else if(opt=='h'){
       /*print help*/
@@ -409,7 +409,7 @@ int main(int argc,char* argv[]){
       fprintf(stdout,"      4  minimization steps             \n");
       fprintf(stdout,"      5  model definition               \n");
       fprintf(stdout," -N  max minimization steps (default 500) \n");
-      return(0);
+      exit(0);
     }
     else if(opt=='e'){
       /* set the minimization tolerance */
