@@ -51,7 +51,7 @@ int main(int argc,char* argv[]){
     }
     else if(opt=='?'){
       fprintf(stderr,"option %c not recognized\n",optopt);
-      return(-1);
+      exit(-1);
     }
     else if(opt=='h'){
       /*print help*/
@@ -79,7 +79,7 @@ int main(int argc,char* argv[]){
       fprintf(stdout," -F  specify the input fields separators (default \" \\t\")\n");
       fprintf(stdout," -h  this help\n");
       fprintf(stdout," -v  verbose mode\n");
-      return(0);
+      exit(0);
     }
     else if(opt=='W'){
       o_position=atoi(optarg);
@@ -574,5 +574,5 @@ int main(int argc,char* argv[]){
     fprintf(stderr,"you asked for something impossible! check %s -h\n",argv[0]);      
   }
   
-  return(0);
+  exit(0);
 }
