@@ -2391,7 +2391,7 @@ int main(int argc,char* argv[]){
     }
     else if(opt=='?'){
       fprintf(stderr,"option %c not recognized\n",optopt);
-      return(-1);
+      exit(-1);
     }
     else if(opt=='h'){
       /*print help*/
@@ -2445,7 +2445,7 @@ int main(int argc,char* argv[]){
       fprintf(stdout,"                   of 'file', considering all possible pairings.\n");
       fprintf(stdout," gbtest KW -p < file  compute the Kruscal-Wallis test and its p-score\n");
       fprintf(stdout,"                      on the first three columns of data in 'file' \n");
-      finalize_program(); return(0);
+      finalize_program(); exit(0);
     }
     else if(opt=='F'){
       /*set the fields separator string*/
@@ -2784,6 +2784,6 @@ int main(int argc,char* argv[]){
   free(length);
   free(tgroup);
 
-  finalize_program(); return(0);
+  finalize_program(); exit(0);
 }
 
