@@ -1267,8 +1267,8 @@ void moment(const double data[], const size_t size, double *ave, double *adev,
   double lmin,lmax,lave,ladev,lsdev,lvar,lskew,lcurt; /* local vars */
 
   if (size == 0) {
-    fprintf(stderr,"WARNING (%s): at least 1 observation is required\n",
-	    GB_PROGNAME);
+    fprintf (stderr,"WARNING (%s): Sample size is zero. All stats are set to NaN\n", 
+	       GB_PROGNAME);
 
     *min=NAN;
     *max=NAN;
@@ -1278,7 +1278,6 @@ void moment(const double data[], const size_t size, double *ave, double *adev,
     *sdev=NAN;
     *skew=NAN;
     *curt=NAN;
-  
 
     return ;
   }
